@@ -7,13 +7,21 @@ Glib::Event - Coerce Glib into using the Event module as event loop.
  use Glib::Event;
 
  # example with Gtk2:
- use Gtk2;
+ use Gtk2 -init;
  use Glib::Event;
  use Event; # any order
  Event->timer (after => 1, interval => 1, cb => sub { print "I am here!\n" });
  main Gtk2;
  # etc., it just works
 
+ # You can even move the glib mainloop into a coroutine:
+ use Gtk2 -init;
+ use Coro;
+ use Coro::Event;
+ use Glib::Event;
+ async { main Gtk2 };
+ # ... do other things
+
 =head1 DESCRIPTION
 
 This module coerces the Glib event loop to use the Event module as
@@ -35,6 +43,12 @@ problems.
 Loading this module will automatically "patch" the default context of
 libglib, so normally nothing more is required.
 
+=item * Glib does not allow recursive invocations.
+
+This means that none of your event watchers might call into Glib
+functions or functions that might call glib functions (basically all Gtk2
+functions). It might work, but that's your problem....
+
 =cut
 
 package Glib::Event;
@@ -45,7 +59,7 @@ use Event ();
 our $default_poll_func;
 
 BEGIN {
-   $VERSION = 0.1;
+   $VERSION = 0.2;
 
    require XSLoader;
    XSLoader::load (Glib::Event, $VERSION);
